//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#include <algorithm>

#include "lfc1/datetime/cdate.hpp"

using namespace std;

namespace lfc1 { namespace datetime {

///	@brief This function creates a CDateDuration object.
///
///	@param[in]	avDuration	The date duration.
///	@param[in]	avUnit		The unit of measure of the date duration.
///
CDateDuration::CDateDuration(int avDuration, EUnits avUnit) noexcept
:	mvDuration {avDuration},
	mvUnit {avUnit}
{
}

///	@brief This function copy constructs a CDateDuration object.
///
///	@param[in]	arRHS	The CDateDuration object to be copied.
///
CDateDuration::CDateDuration(const CDateDuration& arRHS) noexcept
:	mvDuration {arRHS.mvDuration},
	mvUnit {arRHS.mvUnit}
{
}

///	@brief This function move constructs a CDateDuration object.
///
///	@param[in]	arRHS	The CDateDuration object to be moved.
///
CDateDuration::CDateDuration(CDateDuration&& arRHS) noexcept
:	mvDuration {arRHS.mvDuration},
	mvUnit {arRHS.mvUnit}
{
}

///	@brief This function destroys a CDateDuration object.
///
CDateDuration::~CDateDuration() noexcept
{
}

///	@brief This function assigns a CDateDuration object to another CDateDuration object.
///
///	@param[in]	arRHS	The CDateDuration object to assign to another CDateDuration object.
///
///	@return	The CDateDuration object assigned to.
///
CDateDuration& CDateDuration::operator=(const CDateDuration& arRHS) noexcept
{
	mvDuration = arRHS.mvDuration;
	mvUnit = arRHS.mvUnit;
	return *this;
}

///	@brief This function moves a CDateDuration object to another CDateDuration object.
///
///	@param[in]	arRHS	The CDateDuration object to move to another CDateDuration object.
///
///	@return	The CDateDuration object assigned to.
///
CDateDuration& CDateDuration::operator=(CDateDuration&& arRHS) noexcept
{
	mvDuration = arRHS.mvDuration;
	mvUnit = arRHS.mvUnit;
	return *this;
}

///	@brief This function obtains the date duration.
///
///	@return The date duration.
///
int CDateDuration::mvGetDuration() const noexcept
{
	return mvDuration;
}

///	@brief This function obtains the unit of the date duration.
///
///	@return The unit of the date duration.
///
CDateDuration::EUnits CDateDuration::mvGetUnit() const noexcept
{
	return mvUnit;
}

///	@brief This function swaps a CDateDuration object with another CDateDuration object.
///
///	@param[in,out]	arRHS	The CDateDuration object to swap with.
///
void CDateDuration::swap(CDateDuration& arRHS) noexcept
{
	using std::swap;
	swap(mvDuration, arRHS.mvDuration);
	swap(mvUnit, arRHS.mvUnit);
}

///	@ingroup LFC1_DATETIME
///	@headerfile lfc1/datetime/cdate.hpp
///	@brief This function overloads std::swap for CDateDuration objects.
///
///	@param[in,out]	arLHS	The first object to swap.
///	@param[in,out]	arRHS	The second object to swap.
///
void swap(CDateDuration& arLHS, CDateDuration& arRHS) noexcept
{
	arLHS.swap(arRHS);
}

} /* namespace datetime */ } /* namespace lfc1 */

//============================================================================================================
//	End of Code
//============================================================================================================
