//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#include <algorithm>

#include "lfc1/datetime/cdatetime.hpp"

using namespace std;

namespace lfc1 { namespace datetime {

///	@brief This function creates a CDateTimeDuration object.
///
///	@param[in]	avDuration	The date duration.
///	@param[in]	avUnit		The unit of measure of the date duration.
///
CDateTimeDuration::CDateTimeDuration(int avDuration, EUnits avUnit) noexcept
:	mvDuration {avDuration},
	mvUnit {avUnit}
{
}

///	@brief This function copy constructs a CDateTimeDuration object.
///
///	@param[in]	arRHS	The CDateTimeDuration object to be copied.
///
CDateTimeDuration::CDateTimeDuration(const CDateTimeDuration& arRHS) noexcept
:	mvDuration {arRHS.mvDuration},
	mvUnit {arRHS.mvUnit}
{
}

///	@brief This function move constructs a CDateTimeDuration object.
///
///	@param[in]	arRHS	The CDateTimeDuration object to be moved.
///
CDateTimeDuration::CDateTimeDuration(CDateTimeDuration&& arRHS) noexcept
:	mvDuration {arRHS.mvDuration},
	mvUnit {arRHS.mvUnit}
{
}

///	@brief This function destroys a CDateTimeDuration object.
///
CDateTimeDuration::~CDateTimeDuration() noexcept
{
}

///	@brief This function assigns a CDateTimeDuration object to another CDateTimeDuration object.
///
///	@param[in]	arRHS	The CDateTimeDuration object to assign to another CDateTimeDuration object.
///
///	@return	The CDateTimeDuration object assigned to.
///
CDateTimeDuration& CDateTimeDuration::operator=(const CDateTimeDuration& arRHS) noexcept
{
	mvDuration = arRHS.mvDuration;
	mvUnit = arRHS.mvUnit;
	return *this;
}

///	@brief This function moves a CDateTimeDuration object to another CDateTimeDuration object.
///
///	@param[in]	arRHS	The CDateTimeDuration object to move to another CDateTimeDuration object.
///
///	@return	The CDateTimeDuration object assigned to.
///
CDateTimeDuration& CDateTimeDuration::operator=(CDateTimeDuration&& arRHS) noexcept
{
	mvDuration = arRHS.mvDuration;
	mvUnit = arRHS.mvUnit;
	return *this;
}

///	@brief This function obtains the date duration.
///
///	@return The date duration.
///
int CDateTimeDuration::mvGetDuration() const noexcept
{
	return mvDuration;
}

///	@brief This function obtains the unit of the date duration.
///
///	@return The unit of the date duration.
///
CDateTimeDuration::EUnits CDateTimeDuration::mvGetUnit() const noexcept
{
	return mvUnit;
}

///	@brief This function swaps a CDateTimeDuration object with another CDateTimeDuration object.
///
///	@param[in,out]	arRHS	The CDateTimeDuration object to swap with.
///
void CDateTimeDuration::swap(CDateTimeDuration& arRHS) noexcept
{
	using std::swap;
	swap(mvDuration, arRHS.mvDuration);
	swap(mvUnit, arRHS.mvUnit);
}

///	@ingroup LFC1_DATETIME
///	@headerfile lfc1/datetime/cdatetime.hpp
///	@brief This function overloads std::swap for CDateTimeDuration objects.
///
///	@param[in,out]	arLHS	The first object to swap.
///	@param[in,out]	arRHS	The second object to swap.
///
void swap(CDateTimeDuration& arLHS, CDateTimeDuration& arRHS) noexcept
{
	arLHS.swap(arRHS);
}

} /* namespace datetime */ } /* namespace lfc1 */

//============================================================================================================
//	End of Code
//============================================================================================================
