//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#include <algorithm>

#include "lfc1/datetime/ctime.hpp"

using namespace std;

namespace lfc1 { namespace datetime {

///	@brief This function creates a CTimeDuration object.
///
///	@param[in]	avDuration	The time duration.
///	@param[in]	avUnit		The unit of measure of the time duration.
///
CTimeDuration::CTimeDuration(int avDuration, EUnits avUnit) noexcept
:	mvDuration {avDuration},
	mvUnit {avUnit}
{
}

///	@brief This function copy constructs a CTimeDuration object.
///
///	@param[in]	arRHS	The CTimeDuration object to be copied.
///
CTimeDuration::CTimeDuration(const CTimeDuration& arRHS) noexcept
:	mvDuration {arRHS.mvDuration},
	mvUnit {arRHS.mvUnit}
{
}

///	@brief This function move constructs a CTimeDuration object.
///
///	@param[in]	arRHS	The CTimeDuration object to be moved.
///
CTimeDuration::CTimeDuration(CTimeDuration&& arRHS) noexcept
:	mvDuration {arRHS.mvDuration},
	mvUnit {arRHS.mvUnit}
{
}

///	@brief This function destroys a CTimeDuration object.
///
CTimeDuration::~CTimeDuration() noexcept
{
}

///	@brief This function assigns a CTimeDuration object to another CTimeDuration object.
///
///	@param[in]	arRHS	The CTimeDuration object to assign to another CTimeDuration object.
///
///	@return	The CTimeDuration object assigned to.
///
CTimeDuration& CTimeDuration::operator=(const CTimeDuration& arRHS) noexcept
{
	mvDuration = arRHS.mvDuration;
	mvUnit = arRHS.mvUnit;
	return *this;
}

///	@brief This function moves a CTimeDuration object to another CTimeDuration object.
///
///	@param[in]	arRHS	The CTimeDuration object to move to another CTimeDuration object.
///
///	@return	The CTimeDuration object assigned to.
///
CTimeDuration& CTimeDuration::operator=(CTimeDuration&& arRHS) noexcept
{
	mvDuration = arRHS.mvDuration;
	mvUnit = arRHS.mvUnit;
	return *this;
}

///	@brief This function obtains the time duration.
///
///	@return The time duration.
///
int CTimeDuration::mvGetDuration() const noexcept
{
	return mvDuration;
}

///	@brief This function obtains the unit of the time duration.
///
///	@return The unit of the time duration.
///
CTimeDuration::EUnits CTimeDuration::mvGetUnit() const noexcept
{
	return mvUnit;
}

///	@brief This function swaps a CTimeDuration object with another CTimeDuration object.
///
///	@param[in,out]	arRHS	The CTimeDuration object to swap with.
///
void CTimeDuration::swap(CTimeDuration& arRHS) noexcept
{
	using std::swap;
	swap(mvDuration, arRHS.mvDuration);
	swap(mvUnit, arRHS.mvUnit);
}

///	@ingroup LFC1_DATETIME
///	@headerfile lfc1/datetime/ctime.hpp
///	@brief This function overloads std::swap for CTimeDuration objects.
///
///	@param[in,out]	arLHS	The first object to swap.
///	@param[in,out]	arRHS	The second object to swap.
///
void swap(CTimeDuration& arLHS, CTimeDuration& arRHS) noexcept
{
	arLHS.swap(arRHS);
}

} /* namespace datetime */ } /* namespace lfc1 */

//============================================================================================================
//	End of Code
//============================================================================================================
