//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_DATETIME_CFACETBASE_HPP_
#define _LFC1_DATETIME_CFACETBASE_HPP_

#include <iostream>

#include "lfc1/datetime/datetimeexp.hpp"

namespace lfc1 { namespace datetime {

///	@ingroup LFC1_DATETIME
///	@headerfile lfc1/datetime/cfacetbase.hpp
///	@brief This class serves as the base class for date and time input/output facets.
///
class LFC1_DATETIME_API CFacetBase
{
public:
	// Type definitions
	typedef std::istreambuf_iterator<char> TInIt;	///< This type is the input iterator.
	typedef std::ostreambuf_iterator<char> TOutIt;	///< This type is the output iterator.

protected:
	// Class special operations
	static TInIt smvIgnoreChar
	(
		TInIt avNext,
		TInIt avEnd,
		std::ios_base::iostate& arIoState,
		char avExpectedChar
	) noexcept;
	static TInIt smvGetNumber
	(
		TInIt avNext,
		TInIt avEnd,
		std::ios_base& arIosBase,
		std::ios_base::iostate& arIoState,
		int* apNumber,
		int avDigits,
		char avPadding
	) noexcept;
	static TOutIt smvPutNumber1(TOutIt avOut, int avNumber) noexcept;
	static TOutIt smvPutNumber2Zero(TOutIt avOut, int avNumber) noexcept;
	static TOutIt smvPutNumber2Blank(TOutIt avOut, int avNumber) noexcept;
	static TOutIt smvPutNumber3Zero(TOutIt avOut, int avNumber) noexcept;
	static TOutIt smvPutNumber4Zero(TOutIt avOut, int avNumber) noexcept;

	// Constructors/destructor
	CFacetBase() noexcept;
	CFacetBase(const CFacetBase&) = delete;	///< Not supported.
	CFacetBase(CFacetBase&&) = delete;	///< Not supported.
	virtual ~CFacetBase() noexcept;

	// Assignment
	CFacetBase& operator=(const CFacetBase&) = delete;	///< Not supported.
	CFacetBase& operator=(CFacetBase&&) = delete;	///< Not supported.
};

} /* namespace datetime */ } /* namespace lfc1 */

#endif // _LFC1_DATETIME_CFACETBASE_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
