//============================================================================================================
//	$Id$
//
//	$Author$
//
//	$DateTime$
//============================================================================================================

#ifndef _LFC1_DATETIME_CLANGINFO_HPP_
#define _LFC1_DATETIME_CLANGINFO_HPP_

#include <string>

#include "lfc1/datetime/datetimeexp.hpp"

namespace lfc1 { namespace datetime {

///	@ingroup LFC1_DATETIME
///	@headerfile lfc1/datetime/clanginfo.hpp
///	@brief This class obtains locale specific date and time strings.
///
///	For the getter functions to work correctly for the desired locale, the desired locale must be selected
///	as the global locale.  This is not ideal because imbuing streams with a different locale whose facets
///	uses this class will not work correctly.  Unfortunately, that is how it is in a UNIX environment because
///	locale specific information can only be accessed via C API functions and these functions require the
///	desired locale to be set as the global locale.
///
class LFC1_DATETIME_API CLangInfo
{
public:
	// Class setters/getters
	static std::string smvGetDateFormat();
	static std::string smvGetTime24Format();
	static std::string smvGetTime12Format();
	static std::string smvGetDateTimeFormat();
	static std::string smvGetLongDayName(int avWeekDay);
	static std::string smvGetShortDayName(int avWeekDay);
	static std::string smvGetLongMonthName(int avMonth);
	static std::string smvGetShortMonthName(int avMonth);
	static std::string smvGetAMString();
	static std::string smvGetPMString();

	// Constructors/destructor
	CLangInfo() = delete;	///< Not supported.
	CLangInfo(const CLangInfo&) = delete;	///< Not supported.
	CLangInfo(CLangInfo&&) = delete;	///< Not supported.
	~CLangInfo() = delete;	///< Not supported.

	// Assignment
	CLangInfo& operator=(const CLangInfo&) = delete;	///< Not supported.
	CLangInfo& operator=(CLangInfo&&) = delete;	///< Not supported.
};

} /* namespace datetime */ } /* namespace lfc1 */

#endif // _LFC1_DATETIME_CLANGINFO_HPP_

//============================================================================================================
//	End of Code
//============================================================================================================
